@@ -18,24 +18,28 @@
  *
  * Authors:
  *      Mark McLoughlin <mark@skynet.ie>
+ *      Jonh Wendell <wendell@bani.com.br>
  */
 
 #include <config.h>
 
+#include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <locale.h>
 
 #include "vino-input.h"
 #include "vino-mdns.h"
 #include "vino-server.h"
-#include "vino-shell.h"
 #include "vino-prefs.h"
 #include "vino-util.h"
 #include "vino-dbus-listener.h"
+#include "eggsmclient.h"
 
 #ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
 
-#ifdef G_ENABLE_DEBUG
+#ifdef GNOME_ENABLE_DEBUG
 static void
 vino_debug_gnutls (int         level,
 		   const char *str)
@@ -48,20 +52,40 @@ vino_debug_gnutls (int         level,
 int
 main (int argc, char **argv)
 {
-  GdkDisplay *display;
-  gboolean    view_only;
-  int         i, n_screens;
+  GOptionContext *context;
+  GdkDisplay     *display;
+  gboolean        view_only;
+  int             i, n_screens;
+  GError         *error = NULL;
+  EggSMClient    *client;
 
+  setlocale (LC_ALL, "");
   bindtextdomain (GETTEXT_PACKAGE, VINO_LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  gtk_init (&argc, &argv);
+  context = g_option_context_new (_("- VNC Server for GNOME"));
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+  g_option_context_parse (context, &argc, &argv, &error);
+  if (error)
+    {
+      g_print ("%s\n%s\n",
+	       error->message,
+	       _("Run 'vino-server --help' to see a full list of available command line options"));
+      g_error_free (error);
+      return 1;
+    }
+
+  client = egg_sm_client_get ();
+  egg_sm_client_set_mode (EGG_SM_CLIENT_MODE_NO_RESTART);
+  g_signal_connect (client, "quit",
+		    G_CALLBACK (gtk_main_quit), NULL);
 
   vino_setup_debug_flags ();
 
 #ifdef HAVE_GNUTLS
-#ifdef G_ENABLE_DEBUG
+#ifdef GNOME_ENABLE_DEBUG
   if (_vino_debug_flags & VINO_DEBUG_TLS)
     {
       gnutls_global_set_log_level (10);
@@ -73,7 +97,7 @@ main (int argc, char **argv)
   gtk_window_set_default_icon_name ("preferences-desktop-remote-desktop");
   g_set_application_name (_("GNOME Remote Desktop"));
 
-  if (!vino_shell_register (&argc, argv))
+  if (!vino_dbus_request_name ())
     return 1;
 
   display = gdk_display_get_default ();
@@ -92,8 +116,6 @@ main (int argc, char **argv)
   for (i = 0; i < n_screens; i++)
     vino_prefs_create_server (gdk_display_get_screen (display, i));
 
-  vino_dbus_request_name ();
-
   gtk_main ();
 
   vino_mdns_shutdown ();
